'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-bdeef4f4.js');
const defaultIconPack = require('./default-icon-pack-0ea0e986.js');
const index$1 = require('./index-dbc5b08f.js');
const logger = require('./logger-0e4a4217.js');
const versionTwoApis = require('./versionTwoApis-9c9006ae.js');
require('./default-language-4c779255.js');

const dyteScreenShareToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}";

const deviceCanScreenShare = () => {
  return (typeof navigator !== 'undefined' &&
    typeof navigator.mediaDevices !== 'undefined' &&
    'getDisplayMedia' in navigator.mediaDevices);
};
const DyteScreenShareToggle = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /** Variant */
    this.variant = 'button';
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    /** Language */
    this.t = index$1.useLanguage();
    /**
     * Maximum screen share count (value from preset)
     * -1 denotes there is no limit on maximum
     */
    this.maxScreenShareCount = -1;
    this.screenShareCount = 0;
    this.screenShareEnabled = false;
    this.canScreenShare = false;
    this.shareScreenPermission = 'NOT_REQUESTED';
    this.selfScreenShareListener = ({ screenShareEnabled }) => {
      this.screenShareEnabled = screenShareEnabled;
    };
    this.screenShareListener = ({ screenShareEnabled }) => {
      const currentCount = this.screenShareCount + (screenShareEnabled ? 1 : -1);
      this.screenShareCount = Math.max(currentCount, 0);
    };
    this.participantLeftListener = ({ screenShareEnabled }) => {
      if (screenShareEnabled) {
        // decrement count if participant who left had screenShareEnabled
        // and don't let it go below 0 (just a failsafe)
        this.screenShareCount = Math.max(this.screenShareCount - 1, 0);
      }
    };
    this.mediaPermissionErrorListener = ({ kind, message }) => {
      if (kind === 'screenshare') {
        this.shareScreenPermission = message;
      }
    };
    this.reachedMaxScreenShares = () => {
      // checks if a limit exists, and if limit is reached
      return this.maxScreenShareCount > 0 && this.screenShareCount >= this.maxScreenShareCount;
    };
    this.toggleScreenShare = () => {
      var _a;
      const self = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self;
      if (self == null ||
        !this.canScreenShare ||
        this.reachedMaxScreenShares() ||
        this.hasPermissionError()) {
        return;
      }
      if (self.screenShareEnabled) {
        self.disableScreenShare();
      }
      else {
        self.enableScreenShare();
      }
    };
  }
  connectedCallback() {
    if (!deviceCanScreenShare()) {
      logger.loglevel.error('[dyte-screenshare-toggle] Device does not support screensharing.');
    }
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a, _b, _c, _d;
    (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.participants.joined.removeListener('screenShareUpdate', this.screenShareListener);
    (_b = this.meeting) === null || _b === void 0 ? void 0 : _b.participants.joined.removeListener('participantLeft', this.participantLeftListener);
    (_c = this.meeting) === null || _c === void 0 ? void 0 : _c.self.removeListener('screenShareUpdate', this.selfScreenShareListener);
    (_d = this.meeting) === null || _d === void 0 ? void 0 : _d.self.removeListener('mediaPermissionError', this.mediaPermissionErrorListener);
  }
  meetingChanged(meeting) {
    var _a;
    if (meeting != null) {
      const self = meeting.self;
      this.canScreenShare =
        deviceCanScreenShare() && versionTwoApis.canProduce(versionTwoApis.ProduceType.ScreenShare, self.permissions);
      this.maxScreenShareCount = versionTwoApis.isV2Permissions(meeting.self.permissions)
        ? -1
        : (_a = meeting.self.permissions.maxScreenShareCount) !== null && _a !== void 0 ? _a : -1;
      this.screenShareEnabled = self.screenShareEnabled;
      let screenShareCount = 0;
      for (const participant of meeting.participants.joined.toArray()) {
        if (participant.screenShareEnabled) {
          screenShareCount++;
        }
      }
      this.screenShareCount = screenShareCount;
      meeting.participants.joined.addListener('screenShareUpdate', this.screenShareListener);
      meeting.participants.joined.addListener('participantLeft', this.participantLeftListener);
      self.addListener('screenShareUpdate', this.selfScreenShareListener);
      self.addListener('mediaPermissionError', this.mediaPermissionErrorListener);
    }
  }
  hasPermissionError() {
    return (this.shareScreenPermission === 'SYSTEM_DENIED' ||
      this.shareScreenPermission === 'COULD_NOT_START');
  }
  getState() {
    let tooltipLabel = '';
    let label = '';
    let icon = '';
    let classList = {};
    const hasError = this.hasPermissionError();
    const limitReached = this.reachedMaxScreenShares();
    if (this.screenShareEnabled && !hasError) {
      label = this.t('share_screen_stop');
      icon = this.iconPack.share_screen_stop;
      classList['red-icon'] = true;
    }
    else {
      label = this.t('share_screen_start');
      icon = this.iconPack.share_screen_start;
    }
    if (this.shareScreenPermission === 'SYSTEM_DENIED') {
      tooltipLabel = this.t('perm_sys_denied');
      classList['red-icon'] = true;
    }
    else {
      tooltipLabel = label;
    }
    if (limitReached) {
      tooltipLabel = this.t('Maximum screen share limit reached');
    }
    return { tooltipLabel, label, icon, classList, showWarning: hasError || limitReached };
  }
  render() {
    if (!this.canScreenShare) {
      return null;
    }
    const { tooltipLabel, label, icon, classList, showWarning } = this.getState();
    return (index.h(index.Host, { title: label }, index.h("dyte-tooltip", { placement: "top", kind: "block", label: tooltipLabel, delay: 600, part: "tooltip" }, index.h("dyte-controlbar-button", { part: "controlbar-button", size: this.size, iconPack: this.iconPack, variant: this.variant, label: label, icon: icon, class: classList, onClick: this.toggleScreenShare, disabled: showWarning, showWarning: showWarning }))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteScreenShareToggle.style = dyteScreenShareToggleCss;

exports.dyte_screen_share_toggle = DyteScreenShareToggle;
