import { Component, Host, h, Prop, State, Watch, Event } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
import storeState, { onChange } from '../../lib/store';
import { isV2Theme } from '../../utils/versionTwoApis';
/**
 * A button which toggles visibility of plugins.
 *
 * When clicked it emits a `dyteStateUpdate` event with the data:
 *
 * ```ts
 * { activeSidebar: boolean; sidebar: 'plugins' | 'none' }
 * ```
 */
export class DytePluginsToggle {
  constructor() {
    /** Variant */
    this.variant = 'button';
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.pluginsActive = false;
  }
  connectedCallback() {
    this.statesChanged(this.states);
    onChange('sidebar', () => this.statesChanged());
  }
  statesChanged(s) {
    const states = s || storeState;
    if (states != null) {
      this.pluginsActive = states.activeSidebar === true && states.sidebar === 'plugins';
    }
  }
  togglePlugins() {
    const states = this.states || storeState;
    this.pluginsActive = !((states === null || states === void 0 ? void 0 : states.activeSidebar) && (states === null || states === void 0 ? void 0 : states.sidebar) === 'plugins');
    this.stateUpdate.emit({
      activeSidebar: this.pluginsActive,
      sidebar: this.pluginsActive ? 'plugins' : 'none',
    });
    storeState.activeSidebar = this.pluginsActive;
    storeState.sidebar = this.pluginsActive ? 'plugins' : 'none';
  }
  render() {
    var _a, _b, _c, _d;
    const text = this.t('plugins');
    const theme = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.suggestedTheme;
    if (theme && !isV2Theme(theme) && !((_d = (_c = (_b = theme) === null || _b === void 0 ? void 0 : _b.controlBar) === null || _c === void 0 ? void 0 : _c.elements) === null || _d === void 0 ? void 0 : _d.plugins))
      return;
    return (h(Host, { title: text },
      h("dyte-controlbar-button", { part: "controlbar-button", size: this.size, iconPack: this.iconPack, class: { active: this.pluginsActive }, onClick: () => this.togglePlugins(), icon: this.iconPack.rocket, label: text, variant: this.variant })));
  }
  static get is() { return "dyte-plugins-toggle"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-plugins-toggle.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-plugins-toggle.css"]
  }; }
  static get properties() { return {
    "variant": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "ControlBarVariant",
        "resolved": "\"button\" | \"horizontal\"",
        "references": {
          "ControlBarVariant": {
            "location": "import",
            "path": "../dyte-controlbar-button/dyte-controlbar-button"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Variant"
      },
      "attribute": "variant",
      "reflect": true,
      "defaultValue": "'button'"
    },
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "states": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "States object"
      }
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "pluginsActive": {}
  }; }
  static get events() { return [{
      "method": "stateUpdate",
      "name": "dyteStateUpdate",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emits updated state data"
      },
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      }
    }]; }
  static get watchers() { return [{
      "propName": "states",
      "methodName": "statesChanged"
    }]; }
}
