import { Component, Host, h, Prop, State, Watch } from '@stencil/core';
import { shorten } from '../../utils/string';
import { defaultConfig } from '../../lib/default-ui-config';
import { Render } from '../../lib/render';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
import gracefulStorage from '../../utils/graceful-storage';
import storeState from '../../lib/store';
import { isV2Permissions } from '../../utils/versionTwoApis';
/**
 * A screen shown before joining the meeting, where you can edit your display name,
 * and media settings.
 */
export class DyteSetupScreen {
  constructor() {
    /** Config object */
    this.config = defaultConfig;
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.isJoining = false;
    this.canEditName = true;
    this.join = () => {
      var _a, _b;
      if (this.displayName !== '') {
        this.isJoining = true;
        (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.setName(this.displayName);
        gracefulStorage.setItem('dyte-display-name', this.displayName);
        (_b = this.meeting) === null || _b === void 0 ? void 0 : _b.joinRoom();
      }
    };
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  meetingChanged(meeting) {
    var _a;
    if (meeting != null) {
      this.canEditName = isV2Permissions(meeting.self.permissions)
        ? true
        : (_a = meeting.self.permissions.canEditDisplayName) !== null && _a !== void 0 ? _a : true;
      this.displayName = meeting.self.name;
    }
  }
  render() {
    var _a, _b;
    const disabled = this.displayName.trim() === '';
    const defaults = {
      meeting: this.meeting,
      config: this.config,
      states: this.states || storeState,
      size: this.size,
      iconPack: this.iconPack,
      t: this.t,
    };
    return (h(Host, null,
      h("div", { class: "container" },
        h(Render, { element: "dyte-participant-tile", defaults: defaults, props: { participant: (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self, size: 'md' }, childProps: { participant: (_b = this.meeting) === null || _b === void 0 ? void 0 : _b.self, size: 'md' }, deepProps: true }),
        h("div", { class: "metadata" },
          this.displayName.trim() === '' ? (h("div", { class: "name" }, this.t('Hello there!'))) : (h("div", { class: "label" },
            h("p", null, this.t('Joining as')),
            h("div", { class: "name" }, shorten(this.displayName, 20)))),
          this.canEditName && (h("input", { placeholder: this.t('Your name'), value: this.t(this.displayName), autoFocus: true, onInput: (e) => {
              this.displayName = e.target.value;
            }, onKeyDown: (e) => {
              if (e.key === 'Enter') {
                this.join();
              }
            } })),
          h("dyte-button", { size: "lg", kind: "wide", onClick: this.join, disabled: disabled }, this.isJoining ? h("dyte-spinner", null) : 'Join')))));
  }
  static get is() { return "dyte-setup-screen"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-setup-screen.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-setup-screen.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "config": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "UIConfig",
        "resolved": "UIConfig",
        "references": {
          "UIConfig": {
            "location": "import",
            "path": "../../types/ui-config"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Config object"
      },
      "defaultValue": "defaultConfig"
    },
    "states": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "States"
      }
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "displayName": {},
    "isJoining": {},
    "canEditName": {}
  }; }
  static get watchers() { return [{
      "propName": "meeting",
      "methodName": "meetingChanged"
    }]; }
}
